/* Hazard Analysis of political leaders and health 
The following file replicates the analyses in "Political Loyalty and Leader Health" in QJPS */ 
/*Alastair Smith March 2018 */


set more off
use "QJPS_health_Data_mini.dta", clear


/* organize hazard setup */
gen dateS = date(startdate, "YMD")
format dateS %d
gen dateE = date(enddate, "YMD")
format dateE %d
gen s_ob=mdy(1,1,year) 
replace s_ob=dateS if year==Syear 
gen e_ob=mdy(12,31,year) 
replace e_ob=dateE if Eyear==year
gen fail = (Eyear==year) /* failure = any type of removal */ 
gen DinO =  (Edate== DeathDate) /* died in office */ 
gen killed = (Cause=="Killed"|Cause=="Incident")
gen foreign=(exit=="Foreign") /* Removed by foreign power */

gen eAge=age-e10
label var eAge "Age of leader who starts the year minus life expectancy -- i.e is leader old for the times "
gen ToLive = YEARD-year
gen closeToDeath=1/(ToLive+1)
replace closeToDeath =0 if ToLive>=10 |(ToLive==. & year<=2006)| (Cause=="Killed")|(Cause=="Incident")
/* deal with censoring -- killed -cant see natural death and leaders who are still alive */ 
gen IllHealth=0 
replace IllHealth=1 if (Cause=="Chronic"|(Cause=="Heart Attack"&eAge>0)|(Cause=="Stroke"&eAge>0)|(Cause=="Natural Causes"&eAge>0))
gen Chronic= (Cause=="Chronic")
gen Acute=(Cause=="Acute")
gen closeToDeathC=closeToDeath*Chronic
gen closeToDeathNC=closeToDeath*(1-Chronic)
gen closeToDeathIllH=closeToDeath*IllHealth
gen closeToDeathNoIllH=closeToDeath*(1-IllHealth)

gen WgrowthWB=W*growthWB
gen WcloseToDeathC =W*closeToDeathC 
gen WcloseToDeathNC =W*closeToDeathNC 
gen WcloseToDeathIllH =W*closeToDeathIllH
gen WcloseToDeathNoIllH =W*closeToDeathNoIllH
gen WeAge=W*eAge
gen demautcloseToDeathC=demaut*closeToDeathC
gen demautcloseToDeathNC=demaut*closeToDeathNC
gen demauteAge=demaut*eAge
gen demautgrow=demaut*growthWB

/* exitcodes on Archigos are 
Assassination by Unsupported Individual
Irregular, Other
Popular Protest, with Foreign Support
Popular Protest, without Foreign Suppport
Regular
Removed by Military, with Foreign Support
Removed by Military, without Foreign Support
Removed by Other Government Actors, with Foreign Support
Removed by Other Government Actors, without Foreign Support
Removed by Rebels, with Foreign Support
Removed by Rebels, without Foreign Support
Removed in Military Power Struggle Short of Coup
Removed through Threat of Foreign Force
Still in Office
Unknown*/ 
#delimit;
capture gen DeathRemove=0;
replace DeathRemove=1 if (fail==1 &  foreign==0 &exit=="Natural Death" );
#delimit;
stset e_ob, id(leaderNum) failure(DeathRemove) origin(time Sdate) enter(time s_ob) scale(365.25);

/* define means of removal */
/* Leave office but not by dying naturally */
gen out_not_health=0 ;
replace out_not_health=1 if (fail==1 &  DinO==0 & foreign==0);
label var out_not_health "Leader removed but did not naturally die in office or removed by foreign power";

/* regular removal */
gen regularRemove=0;
replace regularRemove=1 if (fail==1 &  DinO==0 & foreign==0 &(exit=="Regular" |exit=="Retired Due to Ill Health" ));
/* Leave office: IRRegularly - not removed by foriegn and not died in office*/ 
capture gen IRregularRemove=0;
replace IRregularRemove=1 if (fail==1 &  (DinO==0 & Cause~="Killed"  ) & foreign==0 &exit=="Irregular" );

gen IRout= inlist(exitcode, "Popular Protest, without Foreign Support","Removed by Military, without Foreign Support",
"Removed by Other Government Actors, without Foreign Support","Removed by Rebels, without Foreign Support", 
"Removed in Military Power Struggle Short of Coup");

capture gen IRregularRemove2=0;
replace IRregularRemove2=1 if (fail==1  & IRout==1 );

/* Further split up the irregular removal mechanisms */
#delimit;
gen mass=1 if inlist(exitcode, "Popular Protest, without Foreign Support",
"Removed by Rebels, without Foreign Support");
gen elite=1 if inlist(exitcode, "Removed by Military, without Foreign Support",
"Removed by Other Government Actors, without Foreign Support",
 "Removed in Military Power Struggle Short of Coup");
capture gen IRmassRemove=0;
replace IRmassRemove=1 if (fail==1 & mass==1) ;
capture gen IRcoalitionRemove=0;
replace IRcoalitionRemove=1 if (fail==1 & elite==1) ;

/*****************************************************/ 
/***** Various means of leaving office****************/ 
/*****************************************************/
#delimit; 
/* out for any reason */
stset e_ob, id(leaderNum) failure(fail) origin(time Sdate) enter(time s_ob) scale(365.25);
/* out but did not die in office */ 
stset e_ob, id(leaderNum) failure(out_not_health) origin(time Sdate) enter(time s_ob) scale(365.25);
/* regular removal */
stset e_ob, id(leaderNum) failure(regularRemove) origin(time Sdate) enter(time s_ob) scale(365.25);
/* irregular removal */
stset e_ob, id(leaderNum) failure(IRregularRemove) origin(time Sdate) enter(time s_ob) scale(365.25);
/* Irregular removal by masses */ 
stset e_ob, id(leaderNum) failure(IRmassRemove) origin(time Sdate) enter(time s_ob) scale(365.25);
/* Irregular removal by the coalition */
stset e_ob, id(leaderNum) failure(IRcoalitionRemove) origin(time Sdate) enter(time s_ob) scale(365.25);


/************* TAble 1 *******************/
#delimit;
stset e_ob, id(leaderNum) failure(fail) origin(time Sdate) enter(time s_ob) scale(365.25);

estpost tab Cause if fail==1;
eststo m1;
esttab m1 using "output/Table1.tex", replace cells("b(label(freq)) pct(fmt(2))") varlabels(, blist(Total "{hline @width}{break}")) nonumber nomtitle noobs ;


gen cause2 = "Acute" if Cause=="Acute";
replace cause2= "Chronic" if Cause=="Chronic";
replace cause2="Killed" if Cause=="Killed";
replace cause2="Incident" if Cause=="Incident";
replace cause2 = "Unknown/Ambiguous" if Cause=="Ambiguous"|Cause=="Unknown";
replace cause2="Suicide" if Cause=="Suicide"|Cause=="Preemptive Suicide";
replace cause2="Other" if Cause =="Heart Attack"|Cause=="Stroke" | Cause=="Natural Causes";
replace cause2="Long Retirement" if Cause=="" & YEARD~=.;
replace cause2="Alive" if Cause=="" & YEARD==.;
gen main=(Cause=="Acute"|Cause=="Chronic"|Cause=="Killed"|Cause=="Incident");


/************* TAble 2 *******************/
#delimit ; 
tabout cause2 W if fail==1  using "output/Table2.tex", replace cells(freq col) format(0 1) 
stats(chi2) layout(row)  clab(N Col_%) style(tex) bt font(bold) topstr(14cm)  botstr(.);

gen entryAge=(Sdate-BornDate)/365.25;
replace entryAge = (year(Sdate)-yrborn) if entryAge==. ;
drop if entryAge<0;
gen exitAge=(Edate-BornDate)/365.25;
replace exitAge = (year(Edate)-yrborn) if exitAge==. ;

gen deathAge=(DeathDate-BornDate)/365.25;
replace deathAge = (yrdied-yrborn) if deathAge==. ;

gen deathEage=deathAge-e10;
/************* TAble 3 *******************/
#delimit ; 
table fail  W if fail==1, c(  mean entryAge sd entryAge  mean exitAge sd exitAge ) format(%9.2f);

table fail  W if fail==1, c(mean deathAge sd deathAge  ) format(%9.2f);

gen one=1;

table one W if year== YEARD , c( mean deathEage sd deathEage) format(%9.2f);
drop one ;


table fail  W if fail==1, c(median tenure mean tenure sd tenure  ) format(%9.2f);

table fail  W if fail==1, c( median retirement mean retirement sd retirement) format(%9.2f);

#delimit cr
/* Ranksum tests */
ranksum entryAge if (W==0|W==1) & fail==1,by(W)
ranksum entryAge if (W==0.25|W==1) & fail==1,by(W)
ranksum entryAge if (W==0.5|W==1) & fail==1,by(W)
ranksum entryAge if (W==0.75|W==1)& fail==1 ,by(W)

/* mean tests */
ttest entryAge if (W==0|W==1) & fail==1,by(W)
ttest entryAge if (W==0.25|W==1) & fail==1,by(W)
ttest entryAge if (W==0.5|W==1) & fail==1,by(W)
ttest entryAge if (W==0.75|W==1)& fail==1 ,by(W)

/* Ranksum tests */
ranksum exitAge if (W==0|W==1) & fail==1,by(W)
ranksum exitAge if (W==0.25|W==1) & fail==1,by(W)
ranksum exitAge if (W==0.5|W==1) & fail==1,by(W)
ranksum exitAge if (W==0.75|W==1)& fail==1 ,by(W)

/* mean tests */
ttest exitAge if (W==0|W==1) & fail==1,by(W)
ttest exitAge if (W==0.25|W==1) & fail==1,by(W)
ttest exitAge if (W==0.5|W==1) & fail==1,by(W)
ttest exitAge if (W==0.75|W==1)& fail==1 ,by(W)


/* Ranksum tests */
ranksum deathAge if (W==0|W==1) & fail==1,by(W)
ranksum deathAge if (W==0.25|W==1) & fail==1,by(W)
ranksum deathAge if (W==0.5|W==1) & fail==1,by(W)
ranksum deathAge if (W==0.75|W==1)& fail==1 ,by(W)

/* mean tests */
ttest deathAge if (W==0|W==1) & fail==1,by(W)
ttest deathAge if (W==0.25|W==1) & fail==1,by(W)
ttest deathAge if (W==0.5|W==1) & fail==1,by(W)
ttest deathAge if (W==0.75|W==1)& fail==1 ,by(W)

/* Ranksum tests */
ranksum deathEage if (W==0|W==1) & fail==1,by(W)
ranksum deathEage if (W==0.25|W==1) & fail==1,by(W)
ranksum deathEage if (W==0.5|W==1) & fail==1,by(W)
ranksum deathEage if (W==0.75|W==1)& fail==1 ,by(W)

/* mean tests */
ttest deathEage if (W==0|W==1) & fail==1,by(W)
ttest deathEage if (W==0.25|W==1) & fail==1,by(W)
ttest deathEage if (W==0.5|W==1) & fail==1,by(W)
ttest deathEage if (W==0.75|W==1)& fail==1 ,by(W)

/* Ranksum tests */
ranksum tenure if (W==0|W==1) & fail==1,by(W)
ranksum tenure if (W==0.25|W==1) & fail==1,by(W)
ranksum tenure if (W==0.5|W==1) & fail==1,by(W)
ranksum tenure if (W==0.75|W==1)& fail==1 ,by(W)

/* mean tests */
ttest tenure if (W==0|W==1) & fail==1,by(W)
ttest tenure if (W==0.25|W==1) & fail==1,by(W)
ttest tenure if (W==0.5|W==1) & fail==1,by(W)
ttest tenure if (W==0.75|W==1)& fail==1 ,by(W)

/* Ranksum tests */
ranksum retirement if (W==0|W==1) & fail==1,by(W)
ranksum retirement if (W==0.25|W==1) & fail==1,by(W)
ranksum retirement if (W==0.5|W==1) & fail==1,by(W)
ranksum retirement if (W==0.75|W==1)& fail==1 ,by(W)

/* mean tests */
ttest retirement if (W==0|W==1) & fail==1,by(W)
ttest retirement if (W==0.25|W==1) & fail==1,by(W)
ttest retirement if (W==0.5|W==1) & fail==1,by(W)
ttest retirement if (W==0.75|W==1)& fail==1 ,by(W)





/*********************** Survival Analysis ************************/
/* Any way to leave office */ 
stset e_ob, id(leaderNum) failure(fail) origin(time Sdate) enter(time s_ob) scale(365.25)
/* note that stata reports 14  observations end on or before enter() 
- these are leaders in office for a single day */

/***** BAsic Description of Survival */
sts test W

sts graph if _t<20, by(W) 
sts graph if _t<20, by(W) haz

#delimit;
 sts graph if _t<10, by(W) 
 plot1opts(recast(line) lcolor(black) lwidth(thick) lpattern(solid)) 
 plot2opts(recast(line) lcolor(red) lwidth(thick) lpattern(dash)) 
 plot3opts(recast(line) lcolor(blue) lwidth(thick) lpattern(dot)) 
plot4opts(recast(line) lcolor(green) lwidth(thick) lpattern(tight_dot))
plot5opts(recast(line) lcolor(dknavy) lwidth(thick) lpattern(dash_dot)) 
ytitle(Survival (any form of deposition)) xtitle("Time, years") name(surv,replace);
graph export figs/Figure1.pdf ,replace;
#delimit cr       



/* very basic analysis */ 

stcox eAge W S
estat phtest,detail
streg eAge W S , dist(wei) anc(W) 
streg eAge W S lgdppc lpop growthWB , dist(wei) anc(W)
stcox eAge W S lgdppc lpop growthWB 
estat phtest,detail
capture gen lnT=log(_t+1)
gen WlnT=W*lnT
gen SlnT=S*lnT



streg eAge W S lgdppc lpop growthWB ResR aidGDP c.closeToDeath##c.IllH    , dist(wei) anc(W)


streg eAge W S log_energy lpopBanks closeToDeath IllH, dist(wei) anc(W)


/* Leave office but not by dying naturally 
gen out_not_health=0 
replace out_not_health=1 if (fail==1 &  DinO==0 & foreign==0)*/
label var out_not_health "Leader removed but did not naturally die in office or removed by foreign power"

/* Leave office - not removed by foriegn and not died in office*/ 
stset e_ob, id(leaderNum) failure(out_not_health) origin(time Sdate) enter(time s_ob) scale(365.25)


streg eAge W S lgdppc lpop growthWB c.closeToDeath##c.IllH, dist(wei) anc(W) hr

append using fake
predict hazardhat, ha


#delimit;
twoway (line hazardhat _t if fake==1 & W==0 &  IllHealth==0 &closeToDeath==0 & growthWB==0, 
							lcolor(black) lwidth(thick) lpattern(solid))	
(line hazardhat _t if fake==1 & W==0 &  IllHealth==1 &closeToDeath==1/2 & growthWB==0, 
							lcolor(black) lwidth(thick) lpattern(dot))							
(line hazardhat _t if fake==1 & W==1 &  IllHealth==0 &closeToDeath==0 & growthWB==0, 
							lcolor(red) lwidth(thick) lpattern(dash))
(line hazardhat _t if fake==1 & W==1 &  IllHealth==1 &closeToDeath==1/2 & growthWB==0, 
							lcolor(red) lwidth(thick) lpattern(short dash))
							, xtitle("Time in Office") ytitle("Predicted Hazard")
							t1title("Impact of Institutions and Health on Political Survival")
							legend( off label(1 "W=0, Healthy") label( 3 "W=1, Healthy")
							label( 2 "W=0, Chronically Ill") label( 4 "W=1, Chronically Ill")) 
text(.1 1.5 "W=0, Healthy", place(c) )
text(.23 4 "W=1, Healthy", place(c) )
text(.125 8 "W=0, Chronically Ill", place(c) )
text(.38 8 "W=1, Chronically Ill", place(c) )
name(basicHazardPrediction,replace) ;
graph export figs/basicHazardPrediction.pdf ,replace;
#delimit cr
drop hazardhat
drop if fake==1

streg eAge W S lgdppc lpop growthWB c.closeToDeath##c.Chronic, dist(wei) anc(W) hr
streg eAge W S lgdppc lpop growthWB closeToDeathC closeToDeathNC , dist(wei) anc(W) hr
append using fake
predict hazardhat, ha


#delimit;
twoway (line hazardhat _t if fake==1 & W==0 &  closeToDeathC==0 &closeToDeathNC==0& Chronic==0& growthWB==0, 
							lcolor(black) lwidth(thick) lpattern(solid))	
(line hazardhat _t if fake==1 & W==0 &  closeToDeathC==1/2 &closeToDeathNC==0& Chronic==1&growthWB==0, 
							lcolor(black) lwidth(thick) lpattern(dot))							
(line hazardhat _t if fake==1 & W==1 &  closeToDeathC==0 &closeToDeathNC==0& Chronic==0&growthWB==0, 
							lcolor(red) lwidth(thick) lpattern(dash))
(line hazardhat _t if fake==1 & W==1 &    closeToDeathC==1/2 &closeToDeathNC==0&Chronic==1& growthWB==0, 
							lcolor(red) lwidth(thick) lpattern(short dash))
							, xtitle("Time in Office") ytitle("Predicted Hazard")
							t1title("Impact of Institutions and Health on Political Survival")
							legend( off label(1 "W=0, Healthy") label( 3 "W=1, Healthy")
							label( 2 "W=0, Chronically Ill") label( 4 "W=1, Chronically Ill")) 
text(.1 1.5 "W=0, Healthy", place(c) )
text(.23 4 "W=1, Healthy", place(c) )
text(.135 8 "W=0, Chronically Ill", place(c) )
text(.44 8 "W=1, Chronically Ill", place(c) )
name(basicHazardPredictionChronic,replace) ;
graph export figs/Figure2.pdf ,replace;
#delimit cr
drop hazardhat
drop if fake==1
 
/* Label Variables for output */ 
#delimit;
global vartext " _cons "Const." LW W(t-1) LW2 W2(t-1) lpop Ln(Pop) lgdppc Ln(GDPpc) growthWB Growth 
	eAge "Rel. Age" WeAge "W * Rel. Age" closeToDeath "CloseToDeath" IllHealth "Ill Health" 
	protestAct3 "Protest Level" L2protestAct3 "Protest Level (t-2)" LprotestAct3 "Protest Level (t-1)" Lcl "Civil Liberties(t-1)"
	log_energy Ln(Energy) lpopBanks Ln(PopBanks) ResRents "Resource Rents" aidGDP Aid/GDP 
	logIncomingTenure "Ln(Tenure)"
	revyn "Revolution Y/N"
	closeToDeath "CloseToDeath" 
	closeToDeathC "CloseToDeath: Chronic" 
	closeToDeathNC "CloseToDeath: Non-Chronic" 
	closeToDeathI "CloseToDeath: Chronic (broad)" 
		closeToDeathNI "CloseToDeath: Non-Chronic (broad)" 
		protestremoval "Leader removed by masses"
		success "Protest movement success"
	major_civilwar "Civil War (Large)" minor_civilwar "Civil War (Small)" interstatewar "InterState War"
	WgrowthWB "W * Growth" c.W#c.closeToDeath "W * CloseToDeath" c.W#c.Chronic "W* Chronic"
	c.W#c.closeToDeath#c.Chronic "W* CloseToDeath * Chronic" 
	c.W#c.ResRents "W * Resource Rents"  c.W#c.aidGDP "W * Aid/GDP" c.W#c.eAge "W * Rel. Age"
	c.W#c.closeToDeathC "W * CloseToDeath: Chronic" c.W#c.closeToDeathNC "W * CloseToDeath: Non-Chronic" 
	closeToDeathC "CloseToDeath: Chronic" closeToDeathNC "CloseToDeath: Non-Chronic" 
	WcloseToDeathC "W * CloseToDeath: Chronic" WcloseToDeathNC "W * CloseToDeath: Non-Chronic" 
		LC "Leader Change"  WLC "W * Leader Change" NC "Non-Chronic" WChronic  "W * Chronic" 
		WNC "W * Non-Chronic"
	closeToDeathIllH "CloseToDeath: IllHeath" closeToDeathNoIllH "CloseToDeath: Non-IllHeath"
	WcloseToDeathIllH "W * CloseToDeath: IllHeath" WcloseToDeathNoIllH "W * CloseToDeath: Non-IllHeath"
WgrowthWB "W * Growth" xconst "xconst" xconstcloseToDeathNC "xconst* CloseToDeath: Non-Chronic" 
xconstcloseToDeathC "xconst* CloseToDeath: Chronic" demaut "Polity" demautcloseToDeathC "Polity* CloseToDeath: Chronic"
demautcloseToDeathNC "Polity* CloseToDeath: Non-Chronic" demauteAge "Polity * Rel. Age" demautgrow "Polity * Growth"
	";


/* Main analysis table in QJPS paper (table 5)*/
#delimit;
streg  W S lgdppc lpop growthWB eAge closeToDeathC closeToDeathNC, dist(wei) anc(W);
eststo hwWBChrpola;
streg  W S lgdppc lpop growthWB ResRents eAge closeToDeathC closeToDeathNC, dist(wei) anc(W);
eststo hwWBplusChrpola;
streg  W S lgdppc lpop growthWB Wgrowth eAge WeAge closeToDeathC closeToDeathNC WcloseToDeathC WcloseToDeathNC, dist(wei) anc(W);
eststo hwWBChrpolintacta;
#delimit; /* main analysis table 5 QJPS*/
esttab hwWBChrpola hwWBplusChrpola hwWBChrpolintacta using "output/Table5.tex" ,  replace
	cells(b(star fmt(3))  se(fmt(3) par)) eqlabels(\$X\beta$  Ln(p)) stats( N N_sub N_fail ll,
	labels("Observations" "Number of Leaders" "Failures" "LogLikelihood")fmt(0 0 0 3)) style(tex) varlabels($vartext)
	order(W S closeToDeathC closeToDeathNC WcloseToDeathC WcloseToDeathNC 
	eAge WeAge lgdppc 
	lpop growthWB WgrowthWB ResRents)
	nonumbers mtitles("M1" "M2" "M3")
	 title("Determinants of Domestic Deposition (Weibull Model) \label{tab:basicWeibulillheathChronic}") addnotes("\tiny{$* p<0.05, ** p<0.01, *** p<0.001$ }");	


/* Control for Term limits: remove all observation of lame ducks: data from Carter and Nordstrom 2017  */ 
#delimit;
streg  W S lgdppc lpop growthWB eAge closeToDeathC closeToDeathNC  if Lame~=1 & year>=1960 &year<=2001, dist(wei) anc(W);
eststo hwWBChrpolaTL;
streg  W S lgdppc lpop growthWB ResRents eAge closeToDeathC closeToDeathNC  if Lame~=1 & year>=1960 &year<=2001,  dist(wei) anc(W);
eststo hwWBplusChrpolaTL;
streg  W S lgdppc lpop growthWB Wgrowth eAge WeAge closeToDeathC closeToDeathNC WcloseToDeathC WcloseToDeathNC  if Lame~=1 & year>=1960 &year<=2001, dist(wei) anc(W);
eststo hwWBChrpolintactaTL;
 
#delimit; 	
esttab hwWBChrpolaTL hwWBplusChrpolaTL hwWBChrpolintactaTL using "output/TableA4.tex",replace cells(b(star fmt(3))  se(fmt(3) par)) eqlabels(\$X\beta$  Ln(p)) stats( N N_sub N_fail ll,
	labels("Observations" "Number of Leaders" "Failures" "LogLikelihood")fmt(0 0 0 3)) style(tex) varlabels($vartext)
	order(W S closeToDeathC closeToDeathNC WcloseToDeathC WcloseToDeathNC 
	eAge WeAge lgdppc 
	lpop growthWB WgrowthWB ResRents) nonumbers mtitles("M1" "M2" "M3")
	 title("Determinants of Domestic Deposition (Excludes Term Limited Lame Ducks, 1960-2001)\label{tab:basicWeibulillheathTL}") 
	  addnotes("\tiny{$* p<0.05, ** p<0.01, *** p<0.001$ }");
 
	
 
 
 
#delimit;
streg  W S lgdppc lpop growthWB eAge closeToDeathIllH closeToDeathNoIllH, dist(wei) anc(W);
eststo hwWBIHpola;
streg  W S lgdppc lpop growthWB ResRent eAge closeToDeathIllH closeToDeathNoIllH, dist(wei) anc(W);
eststo hwWBplusIHpola;
streg  W S lgdppc lpop growthWB Wgrowth eAge WeAge closeToDeathIllH closeToDeathNoIllH WcloseToDeathIllH WcloseToDeathNoIllH, dist(wei) anc(W);
eststo hwWBIHpolintacta;

#delimit; 
esttab hwWBIHpola hwWBplusIHpola hwWBIHpolintacta using "output/TableA1.tex" ,  replace
	cells(b(star fmt(3))  se(fmt(3) par)) eqlabels(\$X\beta$  Ln(p)) stats( N N_sub N_fail ll,
	labels("Observations" "Number of Leaders" "Failures" "LogLikelihood")fmt(0 0 0 3)) style(tex) varlabels($vartext)
	order(W S  closeToDeathIllH closeToDeathNoIllH WcloseToDeathIllH WcloseToDeathNoIllH
	eAge WeAge lgdppc 
	lpop growthWB WgrowthWB ResRents) nonumbers mtitles("M1" "M2" "M3")
	 title("Determinants of Domestic Deposition (Weibull Model, Ill Health)\label{tab:basicWeibulIllHealth}")
	  addnotes("\tiny{$* p<0.05, ** p<0.01, *** p<0.001$ }");

/* With Polity */
#delimit;
streg  demaut lgdppc lpop growthWB eAge closeToDeathC closeToDeathNC, dist(wei) anc(demaut);
eststo deamut1;
streg  demaut lgdppc lpop growthWB ResRents eAge closeToDeathC closeToDeathNC, dist(wei) anc(demaut);
eststo demaut2;
streg  demaut lgdppc lpop growthWB demautgrow eAge demauteAge closeToDeathC closeToDeathNC demautcloseToDeathC demautcloseToDeathNC, dist(wei) anc(demaut);
eststo demaut3;
#delimit; 	
esttab deamut1 demaut2 demaut3 using "output/TableA2.tex",replace cells(b(star fmt(3)) 
 se(fmt(3) par)) eqlabels(\$X\beta$  Ln(p)) stats( N N_sub N_fail ll,
	labels("Observations" "Number of Leaders" "Failures" "LogLikelihood")fmt(0 0 0 3)) style(tex) varlabels($vartext)
	order(demaut  closeToDeathC closeToDeathNC demautcloseToDeathC demautcloseToDeathNC 
	eAge demauteAge lgdppc 
	lpop growthWB demautgrowthWB ResRents) nonumbers mtitles("M1" "M2" "M3")
	 title("Determinants of Domestic Deposition (Weibull Model, Polity Measure of Institutions)\label{tab:basicWeibuldemaut}")
	  addnotes("\tiny{$* p<0.05, ** p<0.01, *** p<0.001$ }");
	 
	

/* Repeat Basic Model with W and S modeled in ancilliary parameter */ 	
#delimit;
streg  W S lgdppc lpop growthWB eAge closeToDeathC closeToDeathNC, dist(wei) anc(W S);
eststo hwWBChrpolaS;
streg  W S lgdppc lpop growthWB ResRents eAge closeToDeathC closeToDeathNC, dist(wei) anc(W S);
eststo hwWBplusChrpolaS;
streg  W S lgdppc lpop growthWB Wgrowth eAge WeAge closeToDeathC closeToDeathNC WcloseToDeathC WcloseToDeathNC, dist(wei) anc(W S);
eststo hwWBChrpolintactaS;

#delimit; 
esttab hwWBChrpolaS hwWBplusChrpolaS hwWBChrpolintactaS using "output/TableA5.tex" ,  replace
	cells(b(star fmt(3))  se(fmt(3) par)) eqlabels(\$X\beta$  Ln(p)) stats( N N_sub N_fail ll,
	labels("Observations" "Number of Leaders" "Failures" "LogLikelihood")fmt(0 0 0 3)) style(tex) varlabels($vartext)
	order(W S  closeToDeathC closeToDeathNC WcloseToDeathC WcloseToDeathNC
	eAge WeAge lgdppc 
	lpop growthWB WgrowthWB ResRents) nonumbers mtitles("M1" "M2" "M3")
	 title("Determinants of Domestic Deposition (Weibull Model, W and S as Ancillary Parameters)\label{tab:basicWeibulillheathS}")
	  addnotes("\tiny{$* p<0.05, ** p<0.01, *** p<0.001$ }");
	 ;	


#delimit; 
replace xconst=. if xconst<0; 
capture gen xconstcloseToDeathC =xconst*WcloseToDeathC; 
capture gen xconstcloseToDeathNC=xconst*closeToDeathNC;
/* Main analysis table with addition of xconst as the component of polity not in W */
#delimit;
streg  W S xconst lgdppc lpop growthWB eAge closeToDeathC closeToDeathNC, dist(wei) anc(W xconst);
eststo xconst1;
streg  W S xconst lgdppc lpop growthWB ResRents eAge closeToDeathC closeToDeathNC, dist(wei) anc(W xconst);
eststo xconst2;
streg  W S xconst lgdppc lpop growthWB Wgrowth eAge WeAge closeToDeathC closeToDeathNC WcloseToDeathC WcloseToDeathNC
xconstcloseToDeathC xconstcloseToDeathNC, dist(wei) anc(W xconst);
eststo xconst3;

#delimit; 	
esttab xconst1 xconst2 xconst3 using "output/TableA3.tex",replace cells(b(star fmt(3)) 
 se(fmt(3) par)) eqlabels(\$X\beta$  Ln(p)) stats( N N_sub N_fail ll,
	labels("Observations" "Number of Leaders" "Failures" "LogLikelihood")fmt(0 0 0 3)) style(tex) varlabels($vartext)
	order(W S xconst  closeToDeathC closeToDeathNC WcloseToDeathC WcloseToDeathNC xconstcloseToDeathC xconstcloseToDeathNC
	eAge WeAge lgdppc 
	lpop growthWB WgrowthWB ResRents) nonumbers mtitles("M1" "M2" "M3")
	 title("Determinants of Domestic Deposition (Weibull Model, Addition of Executive Constraints from Polity Index)\label{tab:basicWeibulxconst}")
	  addnotes("\tiny{$* p<0.05, ** p<0.01, *** p<0.001$ }");
	 
	
/* Replicate with stcox model */ 
#delimit;
stcox  W S lgdppc lpop growthWB eAge c.closeToDeath##c.IllH ;
eststo cox1;
estat phtest,detail;
stcox W WlnT S lgdppc lpop growthWB eAge c.closeToDeath##c.IllH ;
eststo cox2;
estat phtest,detail;
stcox W WlnT S SlnT lgdppc lpop growthWB eAge c.closeToDeath##c.IllH ;
eststo cox3;
estat phtest,detail;

#delimit;
stcox  W S lgdppc lpop growthWB eAge closeToDeathC closeToDeathNC;
eststo cox1c;
estat phtest,detail;
stcox W WlnT S lgdppc lpop growthWB eAge closeToDeathC closeToDeathNC ;
eststo cox2c;
estat phtest,detail;
stcox W WlnT S SlnT lgdppc lpop growthWB eAge closeToDeathC closeToDeathNC ;
eststo cox3c;
estat phtest,detail;

#delimit;
esttab cox1c cox2c cox3c using "output/TableA6.tex" ,  replace
	cells(b(star fmt(3))  se(fmt(3) par)) eqlabels(\$X\beta$  Ln(p)) stats( N N_sub N_fail ll,
	labels("Observations" "Number of Leaders" "Failures" "LogLikelihood")fmt(0 0 0 3)) style(tex) varlabels($vartext)
	order(W S closeToDeathC closeToDeathNC  
	eAge  lgdppc 
	lpop growthWB ) nonumbers mtitles("M1" "M2" "M3")
	 title("Cox Proportionate Hazard Model
The column labeled PH test reports the $\chi^2$ 
statistic for test of the proportionate hazard assumption for model Cox 1. Models Cox 2 and Cox 3 include interactions between $Ln(t)$ and institutional variables.");
	 ;	
	

#delimit;
estout cox1 cox2 cox3 using "output/hazardtab3.tex" ,  replace
	cells(b(star fmt(3))  se(fmt(3) par)) eqlabels(Xb  Ln(p)) stats( N N_sub N_fail ll,
	labels("Observations" "Number of Leaders" "Failures" "LogLikelihood")fmt(0 0 0 3)) style(tex) varlabels($vartext);	
	


/* COMPETING HAZARDS */

/* Leave office: regularly - not removed by foriegn and not died in office
gen regularRemove=0
replace regularRemove=1 if (fail==1 &  DinO==0 & foreign==0 &(exit=="Regular" |exit=="Retired Due to Ill Health" ))*/ 
stset e_ob, id(leaderNum) failure(regularRemove) origin(time Sdate) enter(time s_ob) scale(365.25);

streg  W S lgdppc lpop growthWB  eAge c.closeToDeath##c.IllH, dist(wei) anc(W);
eststo regular1;
streg  W S lgdppc lpop growthWB  eAge c.closeToDeath##c.Chronic, dist(wei) anc(W);
eststo regular1c;
streg  W S lgdppc lpop growthWB  eAge closeToDeathC closeToDeathNC, dist(wei) anc(W);
eststo regular1c;
streg  W c.W##c.S lgdppc lpop c.W##c.growthWB  c.W##c.eAge c.W##c.closeToDeath##c.IllH, dist(wei) anc(W);


streg W S lgdppc lpop growthWB ResR eAge c.closeToDeath##c.IllH, dist(wei) anc(W);
eststo regular2;
#delimit;
/* Leave office: IRRegularly - not removed by foriegn and not died in office*/ 
capture gen IRregularRemove=0;
replace IRregularRemove=1 if (fail==1 &  (DinO==0 & Cause~="Killed"  ) & foreign==0 &exit=="Irregular" );

capture gen IRregularRemove2=0;
replace IRregularRemove2=1 if (fail==1  & IRout==1 );


stset e_ob, id(leaderNum) failure(IRregularRemove) origin(time Sdate) enter(time s_ob) scale(365.25);

streg  W S lgdppc lpop growthWB  eAge c.closeToDeath##c.IllH , dist(wei) anc(W);
streg  W S lgdppc lpop growthWB  eAge closeToDeathC closeToDeathNC, dist(wei) anc(W);
eststo irregular1c;

streg  W S lgdppc lpop growthWB  eAge closeToDeathC closeToDeathNC if W<.7, dist(wei) anc(W);
streg  W S lgdppc lpop growthWB  eAge closeToDeathC closeToDeathNC if W<.8, dist(wei) anc(W);
eststo irregular1cSmallW;



streg  W S lgdppc lpop growthWB  eAge c.closeToDeath##c.IllH if W<.7, dist(wei) anc(W);
eststo irregular1SmallW;

streg  W S c.lgdppc c.lpop c.growthWB c.W##c.ResR c.eAge c.closeToDeath##c.Chronic, dist(wei) anc(W);

streg  W S c.W##(c.lgdppc c.lpop c.growthWB c.ResR c.eAge c.closeToDeath##c.IllH), dist(wei) anc(W);
eststo irregular1;

streg  W S lgdppc lpop c.W##c.growthWB  c.W##c.eAge c.W##c.closeToDeath##c.IllH, dist(wei) anc(W);

streg  W S lgdppc lpop growthWB ResR  year c.W##c.(eAge c.closeToDeath##c.IllH) , dist(wei) anc(W);
eststo irregular2;

streg eAge W S log_energy lpopBanks year c.W##c.closeToDeath##c.IllH, dist(wei) anc(W);

streg eAge W S log_energy lpopBanks  c.closeToDeath c.closeToDeath#c.Chronic c.closeToDeath#c.Acute , dist(wei) anc(W);
stcox eAge W S log_energy lpopBanks  c.closeToDeath c.closeToDeath#c.Chronic  ,noshow;
estat phtest, detail;
predict sch*, scaledsch;
scatter sch2 _t || lfitci sch2 _t;
capture drop sch*;
#delimit;
stcox eAge W S log_energy lpopBanks  c.closeToDeath c.closeToDeath#c.Chronic, 
tvc(W) texp(_t); 

estout regular1 irregular1 regular2 irregular2 using "output/regularirregular.tex" ,  replace
	cells(b(star fmt(3))  se(fmt(3) par)) eqlabels(Xb  Ln(p)) stats( N N_sub N_fail ll,
	labels("Observations" "Number of Leaders" "Failures" "LogLikelihood")fmt(0 0 0 3)) style(tex) varlabels($vartext);	

/* Leave Office by dying */ 
/* Leave office: not killed */ 
#delimit;
capture gen DeathRemove=0;
replace DeathRemove=1 if (fail==1 &  foreign==0 &exit=="Natural Death" );
#delimit;
stset e_ob, id(leaderNum) failure(DeathRemove) origin(time Sdate) enter(time s_ob) scale(365.25);

streg  W S lgdppc lpop growthWB  eAge c.closeToDeath##c.IllH , dist(wei) anc(W);	
eststo meansdeath;
streg  W S lgdppc lpop growthWB  eAge  , dist(wei) anc(W);
eststo meansdeath;
#delimit;
esttab regular1c irregular1c irregular1cSmallW meansdeath using "output/Table6.tex" ,  replace
	cells(b(star fmt(3))  se(fmt(3) par)) eqlabels(\$X\beta$  Ln(p)) stats( N N_sub N_fail ll,
	labels("Observations" "Number of Leaders" "Failures" "LogLikelihood")fmt(0 0 0 3) )
	order(W S closeToDeathC closeToDeathNC  
	eAge  lgdppc 
	lpop growthWB) style(tex) varlabels($vartext) nonumbers mtitles("Regular" "Irregular" "Irregular (\$W<1$)" "Died in Office")
	 title("Competing Hazards for Leader Removal\label{tab:stregmeansChronic}") addnotes("\tiny{$* p<0.05, ** p<0.01, *** p<0.001$ }"); 
#delimit; 	



/* Means of Exit */ 
#delimit; 
gen condition = (fail==1&(DinO==1|foreign==1|regular==1|IRregularRemove==1));	
table  fail W if condition==1, c(  mean regular mean IRregularRemove  mean DinO   mean foreign) format(%9.4f);
table  fail  if condition==1, c(  mean regular mean IRregularRemove  mean DinO   mean foreign) format(%9.4f);
/*table 4 : QJPS paper */
table  fail W if fail==1, c(  mean regular mean IRregularRemove  mean DinO   mean foreign) format(%9.4f);
table  fail  if fail==1, c(  mean regular mean IRregularRemove  mean DinO   mean foreign) format(%9.4f);



/* Table on economic growth. - need to use national year data!*/ 
sort ccode year Syear Sdate;
by ccode year : gen Leaders=_N;
gen LC=(Leaders>1);
by ccode year : gen first=(_n==1);

xtreg growthWB W   closeToDeathC closeToDeathNC eAge LC lgdppc lpop  if first==1 , fe i(ccode);
eststo grow1;
xtreg growthWB W   closeToDeathC closeToDeathNC eAge LC lgdppc lpop if W<1 &first==1 , fe i(ccode);
eststo grow2;

#delimit;
esttab grow1 grow2 using "output/Table7.tex" ,  replace
	cells(b(star fmt(3))  se(fmt(3) par))  stats( N N_g,
	labels("Observations" "Nation FE" )fmt(0 0 ) )
	order(W  closeToDeathC closeToDeathNC  
	eAge  lgdppc 
	lpop ) style(tex) varlabels($vartext) nonumbers mtitles("Growth1" "Growth2 (\$W<1$)")
	 title("Economic Performance as Leaders Get Sick. \\ Nation level fixed effects: The unit of observation is nation-year and the leader based variables are measured for the incoming leader (the leader in power at the start of the year).\label{tab:grow}") addnotes("\tiny{$* p<0.05, ** p<0.01, *** p<0.001$ }"); 
#delimit; 	
